aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h
diff options
context:
space:
mode:
authorGiorgio Arena <giorgio.arena@arm.com>2018-03-15 17:58:20 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:49:16 +0000
commit2d9de0a3fa6ad858e70040124f362799a962bb6a (patch)
tree0a055c5100438a929b3b04945821665d2fef8751 /arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h
parented99f411d52949720a4d64d91664cd71e46b79d5 (diff)
downloadComputeLibrary-2d9de0a3fa6ad858e70040124f362799a962bb6a.tar.gz
COMPMID-1009 Support 4x4 output tile for Winograd Filter Transform on OpenCL.
Change-Id: I68c6453e0f192de659582404f109a89616b9fbb9 Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/124811 Tested-by: Jenkins <bsgcomp@arm.com> Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com> Reviewed-by: Gian Marco Iodice <gianmarco.iodice@arm.com>
Diffstat (limited to 'arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h')
-rw-r--r--arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h b/arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h
index ec5e51482a..c4ae5745b8 100644
--- a/arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h
+++ b/arm_compute/core/CL/kernels/CLWinogradFilterTransformKernel.h
@@ -48,20 +48,22 @@ public:
~CLWinogradFilterTransformKernel() = default;
/** Set the input and output tensor.
*
* @param[in] input Source tensor. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
* kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
* @param[out] output Destination tensor. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
*/
- void configure(const ICLTensor *input, ICLTensor *output);
+ void configure(const ICLTensor *input, ICLTensor *output, const Size2D &output_tile);
/** Static function to check if given info will lead to a valid configuration of @ref CLWinogradFilterTransformKernel
*
* @param[in] input Source tensor info. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
* kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
* @param[in] output Destination tensor info. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
*
* @return a status
*/
- static Status validate(const ITensorInfo *input, const ITensorInfo *output);
+ static Status validate(const ITensorInfo *input, const ITensorInfo *output, const Size2D &output_tile);
// Inherited methods overridden:
void run(const Window &window, cl::CommandQueue &queue) override;
@@ -48,20 +48,22 @@ public:
/** Set the input and output tensor.
*
- * @param[in] input Source tensor. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
- * kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
- * @param[out] output Destination tensor. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
+ * @param[in] input Source tensor. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
+ * kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
+ * @param[out] output Destination tensor. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
+ * @param[in] output_tile Output tile. Currently only 2x2 and 4x4 tiles are supported.
*/
@@ -48,20 +48,22 @@ public:
/** Static function to check if given info will lead to a valid configuration of @ref CLWinogradFilterTransformKernel
*
- * @param[in] input Source tensor info. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
- * kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
- * @param[in] output Destination tensor info. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
+ * @param[in] input Source tensor info. The input is a 4D tensor with dimensions [kernel_x, kernel_y, IFM, OFM] (NCHW data layout).
+ * kernel_x must be 3 and equal to kernel_y. Data types supported: F32.
+ * @param[in] output Destination tensor info. The output is a 3D tensor with dimensions [OFM, IFM, 16]. Data type supported: same as @p input
+ * @param[in] output_tile Output tile. Currently only 2x2 and 4x4 tiles are supported.
*
* @return a status